==> libgtop-2.10.1.tar.bz2: libgtop-2.10.1/sysdeps/linux/siglist.c <==
/* $Id: siglist.c,v 1.7 2005/03/25 12:52:12 bdejean Exp $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/


#include <glibtop/signal.h>

#include <signal.h>


#if 0 /* comment */
perl -nle 'print "{$1,\t\"$1\",\t\"$2\"}," if m|^#define\s*(SIG[A-Z0-9]+).*?/\*\s*(.*?)\s*\*/|'
	< /usr/include/bits/signum.h
#endif


const glibtop_signame glibtop_sys_siglist [] =
{
	{SIGHUP,	"SIGHUP",       "Hangup (POSIX)."},
	{SIGINT,	"SIGINT",       "Interrupt (ANSI)."},
	{SIGQUIT,       "SIGQUIT",      "Quit (POSIX)."},
	{SIGILL,	"SIGILL",       "Illegal instruction (ANSI)."},
	{SIGTRAP,       "SIGTRAP",      "Trace trap (POSIX)."},
	{SIGABRT,       "SIGABRT",      "Abort (ANSI)."},
	{SIGIOT,	"SIGIOT",       "IOT trap (4.2 BSD)."},
	{SIGBUS,	"SIGBUS",       "BUS error (4.2 BSD)."},
	{SIGFPE,	"SIGFPE",       "Floating-point exception (ANSI)."},
	{SIGKILL,       "SIGKILL",      "Kill, unblockable (POSIX)."},
	{SIGUSR1,	"SIGUSR1",      "User-defined signal 1 (POSIX)."},
	{SIGSEGV,	"SIGSEGV",      "Segmentation violation (ANSI)."},
	{SIGUSR2,	"SIGUSR2",      "User-defined signal 2 (POSIX)."},
	{SIGPIPE,       "SIGPIPE",      "Broken pipe (POSIX)."},
	{SIGALRM,       "SIGALRM",      "Alarm clock (POSIX)."},
	{SIGTERM,       "SIGTERM",      "Termination (ANSI)."},
	{SIGSTKFLT,     "SIGSTKFLT",    "Stack fault."},
	{SIGCLD,	"SIGCLD",       "Same as SIGCHLD (System V)."},
	{SIGCHLD,       "SIGCHLD",      "Child status has changed (POSIX)."},
	{SIGCONT,       "SIGCONT",      "Continue (POSIX)."},
	{SIGSTOP,       "SIGSTOP",      "Stop, unblockable (POSIX)."},
	{SIGTSTP,       "SIGTSTP",      "Keyboard stop (POSIX)."},
	{SIGTTIN,       "SIGTTIN",      "Background read from tty (POSIX)."},
	{SIGTTOU,       "SIGTTOU",      "Background write to tty (POSIX)."},
	{SIGURG,	"SIGURG",       "Urgent condition on socket (4.2 BSD)."},
	{SIGXCPU,       "SIGXCPU",      "CPU limit exceeded (4.2 BSD)."},
	{SIGXFSZ,       "SIGXFSZ",      "File size limit exceeded (4.2 BSD)."},
	{SIGVTALRM,     "SIGVTALRM",    "Virtual alarm clock (4.2 BSD)."},
	{SIGPROF,       "SIGPROF",      "Profiling alarm clock (4.2 BSD)."},
	{SIGWINCH,      "SIGWINCH",     "Window size change (4.3 BSD, Sun)."},
	{SIGPOLL,       "SIGPOLL",      "Pollable event occurred (System V)."},
	{SIGIO,		"SIGIO",	"I/O now possible (4.2 BSD)."},
	{SIGPWR,	"SIGPWR",       "Power failure restart (System V)."},
	{SIGSYS,	"SIGSYS",       "Bad system call."},
	{SIGUNUSED,	"SIGUNUSED",	""},
	{0,		NULL,		NULL}
};

==> libgtop-2.14.2.tar.bz2: libgtop-2.14.2/sysdeps/linux/siglist.c <==
/* $Id: siglist.c,v 1.9 2005/12/12 09:38:12 jamesh Exp $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/


#include <config.h>
#include <glibtop/signal.h>

#include <signal.h>


#if 0 /* comment */
perl -nle 'print "{$1,\t\"$1\",\t\"$2\"}," if m|^#define\s*(SIG[A-Z0-9]+).*?/\*\s*(.*?)\s*\*/|'
	< /usr/include/bits/signum.h
#endif


const glibtop_signame glibtop_sys_siglist [] =
{
#ifdef SIGHUP
	{SIGHUP,	"SIGHUP",       "Hangup (POSIX)."},
#endif
#ifdef SIGINT
	{SIGINT,	"SIGINT",       "Interrupt (ANSI)."},
#endif
#ifdef SIGQUIT
	{SIGQUIT,       "SIGQUIT",      "Quit (POSIX)."},
#endif
#ifdef SIGILL
	{SIGILL,	"SIGILL",       "Illegal instruction (ANSI)."},
#endif
#ifdef SIGTRAP
	{SIGTRAP,       "SIGTRAP",      "Trace trap (POSIX)."},
#endif
#ifdef SIGABRT
	{SIGABRT,       "SIGABRT",      "Abort (ANSI)."},
#endif
#ifdef SIGIOT
	{SIGIOT,	"SIGIOT",       "IOT trap (4.2 BSD)."},
#endif
#ifdef SIGBUS
	{SIGBUS,	"SIGBUS",       "BUS error (4.2 BSD)."},
#endif
#ifdef SIGFPE
	{SIGFPE,	"SIGFPE",       "Floating-point exception (ANSI)."},
#endif
#ifdef SIGKILL
	{SIGKILL,       "SIGKILL",      "Kill, unblockable (POSIX)."},
#endif
#ifdef SIGUSR1
	{SIGUSR1,	"SIGUSR1",      "User-defined signal 1 (POSIX)."},
#endif
#ifdef SIGSEGV
	{SIGSEGV,	"SIGSEGV",      "Segmentation violation (ANSI)."},
#endif
#ifdef SIGUSR2
	{SIGUSR2,	"SIGUSR2",      "User-defined signal 2 (POSIX)."},
#endif
#ifdef SIGPIPE
	{SIGPIPE,       "SIGPIPE",      "Broken pipe (POSIX)."},
#endif
#ifdef SIGALRM
	{SIGALRM,       "SIGALRM",      "Alarm clock (POSIX)."},
#endif
#ifdef SIGTERM
	{SIGTERM,       "SIGTERM",      "Termination (ANSI)."},
#endif
#ifdef SIGSTKFLT
	{SIGSTKFLT,     "SIGSTKFLT",    "Stack fault."},
#endif
#ifdef SIGCLD
	{SIGCLD,	"SIGCLD",       "Same as SIGCHLD (System V)."},
#endif
#ifdef SIGCHLD
	{SIGCHLD,       "SIGCHLD",      "Child status has changed (POSIX)."},
#endif
#ifdef SIGCONT
	{SIGCONT,       "SIGCONT",      "Continue (POSIX)."},
#endif
#ifdef SIGSTOP
	{SIGSTOP,       "SIGSTOP",      "Stop, unblockable (POSIX)."},
#endif
#ifdef SIGTSTP
	{SIGTSTP,       "SIGTSTP",      "Keyboard stop (POSIX)."},
#endif
#ifdef SIGTTIN
	{SIGTTIN,       "SIGTTIN",      "Background read from tty (POSIX)."},
#endif
#ifdef SIGTTOU
	{SIGTTOU,       "SIGTTOU",      "Background write to tty (POSIX)."},
#endif
#ifdef SIGURG
	{SIGURG,	"SIGURG",       "Urgent condition on socket (4.2 BSD)."},
#endif
#ifdef SIGXCPU
	{SIGXCPU,       "SIGXCPU",      "CPU limit exceeded (4.2 BSD)."},
#endif
#ifdef SIGXFSZ
	{SIGXFSZ,       "SIGXFSZ",      "File size limit exceeded (4.2 BSD)."},
#endif
#ifdef SIGVTALRM
	{SIGVTALRM,     "SIGVTALRM",    "Virtual alarm clock (4.2 BSD)."},
#endif
#ifdef SIGPROF
	{SIGPROF,       "SIGPROF",      "Profiling alarm clock (4.2 BSD)."},
#endif
#ifdef SIGWINCH
	{SIGWINCH,      "SIGWINCH",     "Window size change (4.3 BSD, Sun)."},
#endif
#ifdef SIGPOLL
	{SIGPOLL,       "SIGPOLL",      "Pollable event occurred (System V)."},
#endif
#ifdef SIGIO
	{SIGIO,		"SIGIO",	"I/O now possible (4.2 BSD)."},
#endif
#ifdef SIGPWR
	{SIGPWR,	"SIGPWR",       "Power failure restart (System V)."},
#endif
#ifdef SIGSYS
	{SIGSYS,	"SIGSYS",       "Bad system call."},
#endif
#ifdef SIGUNUSED
	{SIGUNUSED,	"SIGUNUSED",	""},
#endif
	{0,		NULL,		NULL}
};
